Learn R Programming

jage (version 0.1.0)

find_fuzzies.f: A function for finding and correcting fuzzy posteriors produced by mvcp_est.f

Description

A function for finding and correcting fuzzy posteriors produced by mvcp_est.f

Usage

find_fuzzies.f(cases, prior)

Value

for one case, list object with interpretation and data.table of true age, lower and upper bounds of HDR, mode, and posterior. If multiple cases are entered, only the data.table is returned.

Arguments

cases

as input data.table of rows of collapsed dental development scores, or vector of scores from single individual

prior

as string argument for desired prior

Examples

Run this code
find_fuzzies.f(c(NA,NA,9,10,11,14,15,10,15,11),prior="jeff")

Run the code above in your browser using DataLab